"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
var humanize_1 = require("./humanize");
var mistakes = __importStar(require("./mistakes"));
var process_1 = require("./process");
var sample = "What kind of work do drivers perform? Which human task will AI come to record with its sensors, imitate with its statistical models, and replace with automation?";
describe("humanize", function () {
    test("default configuration", function () {
        expect(humanize_1.humanize(sample, { seed: "seed" }).toString()).toEqual("Wah6 kind of wrok do drivsrs perffo?m Which uhman tsak ill AI come fo recodr iwth its sensors, imitat wiht igs tsatistifal moDels, adn replac iht automatiOn?");
    });
    test("accepts an error configuration", function () {
        expect(humanize_1.humanize(sample, {
            seed: "seed",
            mistakes: [
                {
                    apply: mistakes.capitalize,
                    probability: 0.5
                }
            ]
        }).toString()).toEqual("WhAT KiND oF Work DO driVeRS PERfoRm? WhIch HUmAn TaSK wiLL AI COME To RecorD WItH ITS sENSorS, iMItATe wItH Its STAtISTiCAl mOdELs, AND ReplAcE wiTH AUTOmaTIoN?");
    });
    test("accepts a custom function", function () {
        // TODO: A need to retain word-level sources
        var bar = function (input) {
            if (process_1.isProcessedWord(input)) {
                return __spreadArrays(process_1.process("bar")[0], input.filter(function (processedCharacter) {
                    return /[,.?!\-]/.test(processedCharacter.source);
                }));
            }
            return input;
        };
        expect(humanize_1.humanize(sample, {
            mistakes: [{ apply: bar, probability: 1 }]
        }).toString()).toEqual("bar bar bar bar bar bar bar? bar bar bar bar bar bar bar bar bar bar bar, bar bar bar bar bar, bar bar bar bar?");
    });
    test("accepts a custom function README example", function () {
        var thx = process_1.process("thx")[0];
        var print = function (input) {
            return input.map(function (_a) {
                var source = _a.source;
                return source;
            }).join("");
        };
        var thanks = function (input) {
            // Only re-write words that match 'thanks':
            if (process_1.isProcessedWord(input) && /thanks/i.test(print(input))) {
                return __spreadArrays(thx, input.filter(function (processedCharacter) {
                    return /[,.?!\-]/.test(processedCharacter.source);
                }));
            }
            return input;
        };
        expect(humanize_1.humanize("hey thanks so much!", {
            seed: "1234",
            mistakes: [
                // Mistakes are applied in order from top to bottom
                { apply: mistakes.capitalize, probability: 0.5 },
                { apply: thanks, probability: 1 },
                {
                    apply: function (input) {
                        return mistakes.repeat(input, {
                            "!": 1,
                            x: 1
                        });
                    },
                    probability: 1
                }
            ]
        }).toString()).toEqual("hEY thxxxxxxxxx SO mUCh!!!");
    });
});
